@@ -8,7 +8,6 @@ from rest_framework.authtoken.models import Token
 from rest_framework.test import APITestCase
 
 from authemail.models import SignupCode, PasswordResetCode
-from authemail import wrapper
 
 
 def _get_code_from_email(mail):
@@ -41,10 +40,11 @@ class SignupTests(APITestCase):
         error_dicts = [
             # Email required
             {'payload': {'email': '',
-                         'password': self.pw_visitor},
+                         'password': self.pw_visitor
+                         },
              'status_code': status.HTTP_400_BAD_REQUEST,
              'error': ('email', 'This field may not be blank.')
-            },
+             },
             # Password required
             {'payload': {'email': self.em_visitor,
                          'password': ''},
